﻿using System;

namespace CompareObjField
{
    /// <summary>
    /// 标识对象中要比较的属性
    /// </summary>
    [AttributeUsage(AttributeTargets.Property)]
    public class CompareFieldAttribute : Attribute
    {
        /// <summary>
        /// 指定比较目标字段名称
        /// </summary>
        public string TargetFieldName { get; set; }

        /// <summary>
        /// 所属数据库表名
        /// </summary>
        public string TableName { get; set; }

        /// <summary>
        /// 如果目标对象不存在是否跳过
        /// </summary>
        public bool TargetNotExistsSkip { get; set; }

        /// <summary>
        /// 在比较过程中0等于null或""
        /// </summary>
        public bool ZeroEqualNullOrEmpt { get; set; }

        /// <summary>
        /// 初始化
        /// </summary>
        public CompareFieldAttribute()
        {
            TargetFieldName = "";
            TableName = "";
            TargetNotExistsSkip = false;
            ZeroEqualNullOrEmpt = true;
        }
        /// <summary>
        /// 初始化
        /// </summary>
        /// <param name="targetFieldName">指定比较目标字段名称</param>
        public CompareFieldAttribute(string targetFieldName)
        {
            TargetFieldName = targetFieldName;
        }

        /// <summary>
        /// 初始化
        /// </summary>
        /// <param name="targetFieldName">指定比较目标字段名称</param>
        /// <param name="tableName">所属数据库表名</param>
        /// <param name="targetNotExistsSkip"></param>
        public CompareFieldAttribute(string targetFieldName="", string tableName="", bool targetNotExistsSkip=false)
        {
            TargetFieldName = targetFieldName;
            TableName = tableName;
            TargetNotExistsSkip = targetNotExistsSkip;
        }

    }
}
